@@ -866,6 +866,14 @@ def test_datainfo():
     assert di3["proportion_missing"] == 0
 
 
+def test_grib_get_key_not_exist():
+    a = mv.read(os.path.join(PATH, "tuv_pl.grib"))[0:2]
+    kv = a.grib_get(["silly"])
+    assert kv == [[None], [None]]
+    with pytest.raises(Exception):
+        kv = a.grib_get_long(["silly"])
+
+
 def test_empty_fieldset_contructor():
     f = mv.Fieldset()
     assert type(f) == mv.Fieldset
@@ -910,7 +918,7 @@ def test_fieldset_create_from_glob_path_single():
 def test_fieldset_create_from_glob_path_multi():
     f = mv.Fieldset(path=os.path.join(PATH, "t_*.grib"))
     assert type(f) == mv.Fieldset
-    assert len(f) == 16
+    assert len(f) == 17
     par_ref = [
         ["t", "1000"],
         ["t", "850"],
@@ -928,6 +936,7 @@ def test_fieldset_create_from_glob_path_multi():
         ["z", "1000"],
         ["t", "1000"],
         ["z", "1000"],
+        ["t", "1000"],
     ]
     assert par_ref == mv.grib_get(f, ["shortName", "level"])
 
@@ -937,7 +946,7 @@ def test_fieldset_create_from_glob_paths():
         path=[os.path.join(PATH, "test.g*ib"), os.path.join(PATH, "t_*.grib")]
     )
     assert type(f) == mv.Fieldset
-    assert len(f) == 17
+    assert len(f) == 18
     par_ref = [
         ["2t", "0"],
         ["t", "1000"],
@@ -956,6 +965,7 @@ def test_fieldset_create_from_glob_paths():
         ["z", "1000"],
         ["t", "1000"],
         ["z", "1000"],
+        ["t", "1000"],
     ]
     assert par_ref == mv.grib_get(f, ["shortName", "level"])
 
